package com.cn.fdapfe.biz.mapper;

import java.util.List;
import java.util.Map;

import com.cn.fdapfe.biz.domain.FaultDiagnosisModel;

/**
 * 故障诊断算法模型管理Mapper接口
 * 
 * @author Allem
 * @date 2025-03-07
 */
public interface FaultDiagnosisModelMapper 
{
    /**
     * 查询故障诊断算法模型管理
     * 
     * @param id 故障诊断算法模型管理主键
     * @return 故障诊断算法模型管理
     */
    public FaultDiagnosisModel selectFaultDiagnosisModelById(Long id);

    /**
     * 查询故障诊断算法模型管理列表
     * 
     * @param faultDiagnosisModel 故障诊断算法模型管理
     * @return 故障诊断算法模型管理集合
     */
    public List<FaultDiagnosisModel> selectFaultDiagnosisModelList(FaultDiagnosisModel faultDiagnosisModel);

    /**
     * 新增故障诊断算法模型管理
     * 
     * @param faultDiagnosisModel 故障诊断算法模型管理
     * @return 结果
     */
    public int insertFaultDiagnosisModel(FaultDiagnosisModel faultDiagnosisModel);

    /**
     * 修改故障诊断算法模型管理
     * 
     * @param faultDiagnosisModel 故障诊断算法模型管理
     * @return 结果
     */
    public int updateFaultDiagnosisModel(FaultDiagnosisModel faultDiagnosisModel);

    /**
     * 删除故障诊断算法模型管理
     * 
     * @param id 故障诊断算法模型管理主键
     * @return 结果
     */
    public int deleteFaultDiagnosisModelById(Long id);

    /**
     * 批量删除故障诊断算法模型管理
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteFaultDiagnosisModelByIds(Long[] ids);

    public List<Map<String,Object>> getOptions();
}
